<?php

class Kohana_Account {
    
    protected static $_instance;
    protected $_config;
    protected $_model;

    /**
     * Вовзращает экземпляр класса (singleton-паттерн)
     *
     * @return  instance
     */     
    public static function instance() {
        if(!isset(self::$_instance))
        {
            $config = Kohana::$config->load('account');
            self::$_instance = new self($config);
        }
        return self::$_instance;
    }
    
    private function __construct($config = array()) {
        $this->_config = $config;
        $this->_model = new Model_Account;
    }
    
    /**
     * Генерирует уникальный код активации для данных входных параметров.
     *
     * @param  string $FirstName Имя
     * @param  string $SecondName Отчество
     * @param  string $LastName Фамилия
     * @return  string
     */       
    protected function generateActivationCode()
    {
        $activationCode = Text::random('ABDCEFGHJKLMNPQRSTUVWXYZ123456789', 10);
        return UTF8::strtoupper($activationCode);
    }
    
    public function createTeacher($lastName, $firstName, $secondName, $degreeID, $departamentID)
    {
        $activationCode = $this->generateActivationCode();
        $response = $this->_model->createTeacher($lastName, $firstName, $secondName, $degreeID, $departamentID, $activationCode);
        if($response == -1)
            return -1;
        else
            return $activationCode;
    }
    
    public function createStudent($lastName, $firstName, $secondName, $grade, $groupNum, $facultyID)
    {
        $activationCode = $this->generateActivationCode();
        $response = $this->_model->createStudent($lastName, $firstName, $secondName, $grade, $groupNum, $facultyID, $activationCode);
        if($response == -1)
            return -1;
        else
            return $activationCode;
    }
    
    public function isLoginExists($login)
    {
        $login_count = $this->_model->getAccNumByLogin($login);
        return $login_count > 0;
    }
    
    public function isMailExists($email)
    {
        $email_count = $this->_model->getAccNumByMail($email);
        return $email_count > 0;
    }
    
    public function changeLogin($id, $newLogin)
    {
        $response = $this->_model->changeLogin($id, $newLogin);
        return $response != -1;
    }
    
    public function changeEMail($id, $newEMail)
    {
        $response = $this->_model->changeMail($id, $newEMail);
        return $response != -1;
    }
    
    public function changePassword($id, $newPassword)
    {
        $response = $this->_model->changePassword($id, sha1($newPassword));
        return $response != -1;
    }
        
    
}